<?php namespace Lib\Editeurs;

use \Lib\Contacts\Contact;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\DB as DB;
 
class EditeurGestion extends \Lib\Commun\BaseGestion
{

	protected $editeur;
	protected $contact;

  public function __construct(Editeur $editeur, Contact $contact, EditeurValidation $validation)
  {
    $this->model = $editeur;
    $this->validation = $validation;
    $this->contact = $contact;
  }
		
	public function show($id)
	{
		$editeur = $this->model->find($id);
		return array(
			'editeur' => $editeur,
			'livres' => $editeur->livres,
			'contact' => $editeur->contact->telephone
		);
	}

	public function edit($id)
	{
		$editeur = $this->model->find($id);
		return array(
			'editeur' => $editeur,
			'telephone' => $editeur->contact->telephone
		);
	}

	public function update($id)
	{
		if($this->validation->with(Input::all())->passes())
		{
			$editeur = $this->model->find($id);
			$editeur->nom = Input::get('nom');
			$editeur->contact->telephone = Input::get('telephone');
			DB::transaction(function() use($editeur)
			{	
				$editeur->contact->save();
				$editeur->save(); 
			});
			return true;
		}
		return $this->validation->errors();
	}

	public function store()
	{
		if($this->validation->with(Input::all())->passes())
		{
			$editeur = new $this->model;
			$editeur->nom = Input::get('nom');
			$contact = new $this->contact;
			$contact->telephone = Input::get('telephone');
			DB::transaction(function() use($editeur, $contact)
			{	
				$editeur->save();
				$editeur->contact()->save($contact);
			});
			return true; 
		}
		return $this->validation->errors();
	}

  public function create(){
		return array();  	
  }

	public function destroy($id)
	{
		$editeur = $this->model->find($id);
		if($editeur->livres->count() == 0) {
			$editeur->contact->delete();
			$editeur->delete();
		} else {
			Session::flash('message_danger', 'Cet éditeur ne peut pas être supprimé parce qu\'il possède des livres !');
		}
	}

}