<?php namespace Lib\Livres;

use \Lib\Auteurs\Auteur;
use \Lib\Themes\Theme;
use \Lib\Editeurs\Editeur;
use \Lib\Autoedites\Autoedite;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\DB as DB;
 
class LivreGestion extends \Lib\Commun\BaseGestion
{

	protected $auteur;
	protected $theme;
	protected $editeur;
	protected $autoedite;

  public function __construct(Livre $livre, Auteur $auteur, Theme $theme, Editeur $editeur, Autoedite $autoedite, LivreValidation $validation)
  {
    $this->model = $livre;
    $this->validation = $validation;
    $this->auteur = $auteur;
    $this->theme = $theme;
    $this->editeur = $editeur;
    $this->autoedite = $autoedite;
  }
		
	public function show($id)
	{
		$livre = $this->model->find($id);
		return array(
			'livre' => $livre,
			'auteurs' => $livre->auteurs,
			'theme' => $livre->theme->nom,
			'editeur' => $livre->livrable->nom
		);
	}

	public function edit($id)
	{
		$old = Input::old();
		$livre = $this->model->find($id);
		if(empty($old))	{
			$livrable = $livre->livrable_type == 'Lib\Editeurs\Editeur';
		} else {
			$livrable = $old['livrable'] == 'Lib\Editeurs\Editeur';
		}
		$retour = array(
			'livre' => $livre,
			'select_theme' => $this->theme->all()->lists('nom', 'id'),
			'select_auteurs' => $this->auteur->all()->lists('nom', 'id'),
			'select_editeurs' => $this->editeur->all()->lists('nom', 'id'),
			'select_autoedites' => $this->autoedite->all()->lists('nom', 'id'),
			'livrable' => $livrable
		);		
		$retour['auteurs'] = empty($old) ? $livre->auteurs->toArray(): $old['auteur'];
		return $retour;
	}

	public function update($id)
	{
		if($this->validation->with(Input::all())->passes())
		{
			$livre = $this->model->find($id);	
			DB::transaction(function() use($livre)
			{		
				$livre->auteurs()->sync(Input::get('auteur'));
				$livre->titre = Input::get('titre');
				$livre->theme_id = Input::get('theme_id');
				$type = Input::get('livrable');
				$livre->livrable_type = $type;
				$livre->livrable_id = ($type == 'Lib\Editeurs\Editeur') ? Input::get('editeur_id') : Input::get('autoedite_id');
				$livre->save();
			});
			return true;
		} 
		return $this->validation->errors();
	}

	public function store()
	{
		if($this->validation->with(Input::all())->passes())
		{				
			$livre = new $this->model;
			$livre->theme_id = Input::get('theme_id');
			$livre->titre = Input::get('titre');
			$type = Input::get('livrable');
			$livre->livrable_type = $type;
			$livre->livrable_id = ($type == 'Lib\Editeurs\Editeur') ? Input::get('editeur_id') : Input::get('autoedite_id');
			DB::transaction(function() use($livre)
			{
				$livre->save();
				$auteurs = array_unique(Input::get('auteur'));
				foreach($auteurs as $auteur_id)
				{
					$livre->auteurs()->attach($auteur_id);
				}
			});				
			return true;
		}
		return $this->validation->errors();
	}

  public function create(){
		return array(
			'select_theme' => $this->theme->all()->lists('nom', 'id'),
			'select_auteurs' => $this->auteur->all()->lists('nom', 'id'),
			'select_editeurs' => $this->editeur->all()->lists('nom', 'id'),
			'select_autoedites' => $this->autoedite->all()->lists('nom', 'id')
		);  	
  }

	public function destroy($id)
	{
		$livre = $this->model->find($id);
		DB::transaction(function() use($livre)
		{
			$livre->auteurs()->detach();
			$livre->delete();
		});
	}

}