<?php namespace Lib\Themes;

use \Lib\Categories\Categorie;
use \Lib\Periodes\Periode;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\DB as DB;
 
class ThemeGestion extends \Lib\Commun\BaseGestion
{

	protected $theme;
	protected $categorie;
	protected $periode;

  public function __construct(Theme $theme, Categorie $categorie, Periode $periode, ThemeValidation $validation)
  {
    $this->model = $theme;
    $this->categorie = $categorie;
    $this->periode = $periode;
    $this->validation = $validation;
  }
		
	public function show($id)
	{
		$theme = $this->model->find($id);
		return array(
			'theme' => $theme,
			'livres' => $theme->livres,
			'categories' => $theme->categories,
			'periodes' => $theme->periodes
		);
	}

	public function edit($id)
	{
		$theme = $this->model->find($id);
		$retour = array(
			'theme' => $theme,
			'select_categories' => $this->categorie->all()->lists('nom', 'id'),
			'select_periodes' => $this->periode->all()->lists('nom', 'id')
		);		
		$old = Input::old();
		$retour['categories'] = empty($old) ? $theme->categories->toArray(): $old['categorie'];
		$retour['periodes'] = empty($old) ? $theme->periodes->toArray(): $old['periode'];
		return $retour;
	}

	public function update($id)
	{
		if($this->validation->with(Input::all())->passes())
		{
			$theme = $this->model->find($id);
			DB::transaction(function() use($theme)
			{	
				$theme->categories()->sync(Input::get('categorie'));
				$theme->periodes()->sync(Input::get('periode'));
				$theme->nom = Input::get('nom');
				$theme->save();
			});
			return true;
		}
		return $this->validation->errors();
	}

	public function store()
	{
		if($this->validation->with(Input::all())->passes())
		{
			$theme = new $this->model;
			$theme->nom = Input::get('nom');
			DB::transaction(function() use($theme)
			{	
				$theme->save();
				if(!is_null(Input::get('categorie'))) $theme->categories()->attach(array_unique(Input::get('categorie')));
				if(!is_null(Input::get('periode'))) $theme->periodes()->attach(array_unique(Input::get('periode')));
			});
			return true; 
		}
		return $this->validation->errors();
	}

	public function create(){
		return array(
			'select_categories' => $this->categorie->all()->lists('nom', 'id'),
			'select_periodes' => $this->periode->all()->lists('nom', 'id')
		);  	
	}

	public function destroy($id)
	{
		$theme = $this->model->find($id);
		if($theme->livres->count() == 0) {
			DB::transaction(function() use($theme)
			{	
				$theme->categories()->detach();
				$theme->periodes()->detach();
				$theme->delete();
			});
		} else {
			Session::flash('message_danger', 'Ce thème ne peut pas être supprimé parce qu\'il possède des livres !');
		}
	}

}